@@ -167,6 +167,7 @@ var annotated_dup =
     [ "spa_device_object_info", "structspa__device__object__info.html", "structspa__device__object__info" ],
     [ "spa_dict", "structspa__dict.html", "structspa__dict" ],
     [ "spa_dict_item", "structspa__dict__item.html", "structspa__dict__item" ],
+    [ "spa_dll", "structspa__dll.html", "structspa__dll" ],
     [ "spa_event", "structspa__event.html", "structspa__event" ],
     [ "spa_event_body", "structspa__event__body.html", "structspa__event__body" ],
     [ "spa_fraction", "structspa__fraction.html", "structspa__fraction" ],
@@ -237,6 +238,7 @@ var annotated_dup =
     [ "spa_pod_choice_body", "structspa__pod__choice__body.html", "structspa__pod__choice__body" ],
     [ "spa_pod_control", "structspa__pod__control.html", "structspa__pod__control" ],
     [ "spa_pod_double", "structspa__pod__double.html", "structspa__pod__double" ],
+    [ "spa_pod_dynamic_builder", "structspa__pod__dynamic__builder.html", "structspa__pod__dynamic__builder" ],
     [ "spa_pod_fd", "structspa__pod__fd.html", "structspa__pod__fd" ],
     [ "spa_pod_float", "structspa__pod__float.html", "structspa__pod__float" ],
     [ "spa_pod_fraction", "structspa__pod__fraction.html", "structspa__pod__fraction" ],
