@@ -1,5 +1,6 @@
 var NAVTREEINDEX10 =
 {
+"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0":[10,8,9,3,30],
 "group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1":[10,8,9,3,43],
 "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8":[10,8,9,3,31],
 "group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f":[10,8,9,3,7],
@@ -248,6 +249,5 @@ var NAVTREEINDEX10 =
 "group__spa__node.html#gad8a56491e1cb021d5a6f168a538a6ae5":[10,8,6,127],
 "group__spa__node.html#gada8de413ca18ab054c45f9aba3503af9":[10,8,6,87],
 "group__spa__node.html#gadb0d4466139648f1937c0ea07b150e19":[10,8,6,105],
-"group__spa__node.html#gadcb55c17c2f80d36f159bc763fd309e7":[10,8,6,51],
-"group__spa__node.html#gadcbf11755fca00d5a654a79ee80fdb81":[10,8,6,152]
+"group__spa__node.html#gadcb55c17c2f80d36f159bc763fd309e7":[10,8,6,51]
 };
