@@ -1,5 +1,8 @@
 var NAVTREEINDEX16 =
 {
+"group__spa__types.html#ga4aae17a0b82f8be6d450a8fa3a102225":[10,8,8,12,14],
+"group__spa__types.html#ga4fabe70032a577729bfaa7e1cb231ac6":[10,8,8,12,18],
+"group__spa__types.html#ga5d6f54a630998568dc7b1a3515a434bf":[10,8,8,12,15],
 "group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf":[10,8,8,12,23],
 "group__spa__types.html#ga7991023e0704b7af71b19a08c4a023b7":[10,8,8,12,11],
 "group__spa__types.html#ga886514f37da7215fa5eebe406e2f3b37":[10,8,8,12,9],
@@ -246,8 +249,5 @@ var NAVTREEINDEX16 =
 "page_midi.html#autotoc_md21":[5,7,0,0],
 "page_midi.html#autotoc_md22":[5,7,0,1],
 "page_midi.html#autotoc_md23":[5,7,0,2],
-"page_midi.html#autotoc_md24":[5,7,0,3],
-"page_midi.html#autotoc_md25":[5,7,0,4],
-"page_midi.html#autotoc_md26":[5,7,1],
-"page_midi.html#autotoc_md27":[5,7,1,0]
+"page_midi.html#autotoc_md24":[5,7,0,3]
 };
