@@ -1,5 +1,7 @@
 var NAVTREEINDEX19 =
 {
+"structpw__impl__port.html":[10,5,4,3],
+"structpw__impl__port.html":[10,5,8,2],
 "structpw__impl__port.html":[10,5,7,3],
 "structpw__impl__port__events.html":[10,5,8,1],
 "structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[10,5,8,1,8],
@@ -247,7 +249,5 @@ var NAVTREEINDEX19 =
 "structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62":[10,0,2,2],
 "structpw__stream__control.html#a925311b76a91a9034391da7343865091":[10,0,2,5],
 "structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5":[10,0,2,4],
-"structpw__stream__events.html":[10,0,4],
-"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[10,0,4,7],
-"structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[10,0,4,3]
+"structpw__stream__events.html":[10,0,4]
 };
