@@ -1,5 +1,7 @@
 var NAVTREEINDEX20 =
 {
+"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[10,0,4,7],
+"structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[10,0,4,3],
 "structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02":[10,0,4,11],
 "structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3":[10,0,4,5],
 "structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b":[10,0,4,8],
@@ -247,7 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__i18n.html":[10,8,9,2,1],
 "structspa__i18n.html#a4ca10c865fe33ffff4fd9abb9265c0f8":[10,8,9,2,1,0],
 "structspa__i18n__methods.html":[10,8,9,2,2],
-"structspa__i18n__methods.html#a3aa971d572e886ab027a897a288f767b":[10,8,9,2,2,0],
-"structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675":[10,8,9,2,2,1],
-"structspa__i18n__methods.html#a884391486c3277069fb8ee2f9d754234":[10,8,9,2,2,2]
+"structspa__i18n__methods.html#a3aa971d572e886ab027a897a288f767b":[10,8,9,2,2,0]
 };
